==> mew_6.8-12.debian.tar.xz: debian/dot.mew-theme-subdued.el <==
;;; dot.mew-theme-subdued.el --- subdued highlighting for Mew  -*-mode: emacs-lisp-*-

;; Copyright (C) 2021 Tatsuya Kinoshita

;; Released under the terms of the Creative Commons CC0 1.0 Universal Public
;; Domain Dedication <https://creativecommons.org/publicdomain/zero/1.0/>.

;; Usage: copy to ~/.mew-theme.el, and put (setq mew-theme-file "~/.mew-theme") in ~/.mew

;;; Code:

(when t
  (set-face-foreground 'mew-face-header-subject nil)
  (set-face-bold       'mew-face-header-subject nil)
  (set-face-foreground 'mew-face-header-from nil)
  (set-face-bold       'mew-face-header-from nil)
  (set-face-foreground 'mew-face-header-date nil)
  (set-face-bold       'mew-face-header-date nil)
  (set-face-foreground 'mew-face-header-to nil)
  (set-face-bold       'mew-face-header-to nil)
  (set-face-foreground 'mew-face-header-key nil)
  (set-face-bold       'mew-face-header-key nil)
  (set-face-foreground 'mew-face-header-private nil)
  (set-face-bold       'mew-face-header-private nil)
  (set-face-foreground 'mew-face-header-important nil)
  (set-face-bold       'mew-face-header-important nil)
  (set-face-foreground 'mew-face-header-marginal nil)
  (set-face-bold       'mew-face-header-marginal nil)
  (set-face-foreground 'mew-face-header-warning nil)
  (set-face-bold       'mew-face-header-warning nil)
  (set-face-foreground 'mew-face-header-xmew nil)
  (set-face-bold       'mew-face-header-xmew nil)
  (set-face-foreground 'mew-face-header-xmew-bad nil)
  (set-face-bold       'mew-face-header-xmew-bad nil)
  (set-face-foreground 'mew-face-body-url nil)
  (set-face-bold       'mew-face-body-url nil)
  (set-face-foreground 'mew-face-body-comment nil)
  (set-face-bold       'mew-face-body-comment nil)
  (set-face-foreground 'mew-face-body-cite1 nil)
  (set-face-bold       'mew-face-body-cite1 nil)
  (set-face-foreground 'mew-face-body-cite2 nil)
  (set-face-bold       'mew-face-body-cite2 nil)
  (set-face-foreground 'mew-face-body-cite3 nil)
  (set-face-bold       'mew-face-body-cite3 nil)
  (set-face-foreground 'mew-face-body-cite4 nil)
  (set-face-bold       'mew-face-body-cite4 nil)
  (set-face-foreground 'mew-face-body-cite5 nil)
  (set-face-bold       'mew-face-body-cite5 nil)
  (set-face-foreground 'mew-face-mark-review nil)
  (set-face-bold       'mew-face-mark-review nil)
  (set-face-foreground 'mew-face-mark-escape nil)
  (set-face-bold       'mew-face-mark-escape nil)
  (set-face-foreground 'mew-face-mark-delete nil)
  (set-face-bold       'mew-face-mark-delete nil)
  (set-face-foreground 'mew-face-mark-unlink nil)
  (set-face-bold       'mew-face-mark-unlink nil)
  (set-face-foreground 'mew-face-mark-refile nil)
  (set-face-bold       'mew-face-mark-refile nil)
  (set-face-foreground 'mew-face-mark-unread nil)
  (set-face-bold       'mew-face-mark-unread nil)
  (set-face-foreground 'mew-face-eof-message nil)
  (set-face-bold       'mew-face-eof-message nil)
  (set-face-foreground 'mew-face-eof-part nil)
  (set-face-bold       'mew-face-eof-part nil)
  ;;
  )

(cond
 ((< (display-color-cells) 256)
  (set-face-bold       'mew-face-header-subject t)
  (set-face-bold       'mew-face-header-from t)
  (set-face-bold       'mew-face-header-to t)
  (set-face-bold       'mew-face-eof-message t)
  (set-face-bold       'mew-face-eof-part t)
  ;;
  )
 ((eq (frame-parameter nil 'background-mode) 'dark)
  (set-face-foreground 'mew-face-header-subject "gray89")
  (set-face-bold       'mew-face-header-subject t)
  (set-face-foreground 'mew-face-header-from "gray89")
  (set-face-bold       'mew-face-header-from t)
  (set-face-foreground 'mew-face-header-date "gray70")
  (set-face-bold       'mew-face-header-date t)
  (set-face-foreground 'mew-face-header-to "gray89")
  (set-face-bold       'mew-face-header-to t)
  (set-face-foreground 'mew-face-header-key "gray70")
  (set-face-bold       'mew-face-header-key t)
  (set-face-foreground 'mew-face-header-private "gray70")
  (set-face-bold       'mew-face-header-private t)
  (set-face-foreground 'mew-face-header-important "gray70")
  (set-face-bold       'mew-face-header-important t)
  (set-face-foreground 'mew-face-header-marginal "gray70")
  (set-face-bold       'mew-face-header-marginal t)
  (set-face-foreground 'mew-face-header-warning "gray70")
  (set-face-bold       'mew-face-header-warning t)
  (set-face-foreground 'mew-face-header-xmew "gray70")
  (set-face-bold       'mew-face-header-xmew t)
  (set-face-foreground 'mew-face-header-xmew-bad "gray70")
  (set-face-bold       'mew-face-header-xmew-bad t)
  (set-face-foreground 'mew-face-body-cite1 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite2 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite3 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite4 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite5 "DarkSeaGreen")
  (set-face-foreground 'mew-face-eof-message "gray70")
  (set-face-bold       'mew-face-eof-message t)
  (set-face-foreground 'mew-face-eof-part "gray70")
  (set-face-bold       'mew-face-eof-part t)
  ;;
  )
 (t
  (set-face-foreground 'mew-face-header-subject "gray23")
  (set-face-bold       'mew-face-header-subject t)
  (set-face-foreground 'mew-face-header-from "gray23")
  (set-face-bold       'mew-face-header-from t)
  (set-face-foreground 'mew-face-header-date "gray58")
  (set-face-bold       'mew-face-header-date t)
  (set-face-foreground 'mew-face-header-to "gray23")
  (set-face-bold       'mew-face-header-to t)
  (set-face-foreground 'mew-face-header-key "gray58")
  (set-face-bold       'mew-face-header-key t)
  (set-face-foreground 'mew-face-header-private "gray58")
  (set-face-bold       'mew-face-header-private t)
  (set-face-foreground 'mew-face-header-important "gray58")
  (set-face-bold       'mew-face-header-important t)
  (set-face-foreground 'mew-face-header-marginal "gray58")
  (set-face-bold       'mew-face-header-marginal t)
  (set-face-foreground 'mew-face-header-warning "gray58")
  (set-face-bold       'mew-face-header-warning t)
  (set-face-foreground 'mew-face-header-xmew "gray58")
  (set-face-bold       'mew-face-header-xmew t)
  (set-face-foreground 'mew-face-header-xmew-bad "gray58")
  (set-face-bold       'mew-face-header-xmew-bad t)
  (set-face-foreground 'mew-face-body-cite1 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite2 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite3 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite4 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite5 "DarkGreen")
  (set-face-foreground 'mew-face-eof-message "gray58")
  (set-face-bold       'mew-face-eof-message t)
  (set-face-foreground 'mew-face-eof-part "gray58")
  (set-face-bold       'mew-face-eof-part t)
  ;;
  ))

;;; dot.mew-theme-subdued.el ends here

==> mew_6.8-13.debian.tar.xz: debian/dot.mew-theme-subdued.el <==
;;; dot.mew-theme-subdued.el --- subdued highlighting for Mew  -*-mode: emacs-lisp-*-

;; Copyright (C) 2021 Tatsuya Kinoshita

;; Released under the terms of the CC0 Public Domain Dedication.
;; <https://creativecommons.org/publicdomain/zero/1.0/>

;; Usage: copy to ~/.mew-theme.el, and put (setq mew-theme-file "~/.mew-theme") in ~/.mew

;;; Code:

(when t
  (set-face-foreground 'mew-face-header-subject nil)
  (set-face-bold       'mew-face-header-subject nil)
  (set-face-foreground 'mew-face-header-from nil)
  (set-face-bold       'mew-face-header-from nil)
  (set-face-foreground 'mew-face-header-date nil)
  (set-face-bold       'mew-face-header-date nil)
  (set-face-foreground 'mew-face-header-to nil)
  (set-face-bold       'mew-face-header-to nil)
  (set-face-foreground 'mew-face-header-key nil)
  (set-face-bold       'mew-face-header-key nil)
  (set-face-foreground 'mew-face-header-private nil)
  (set-face-bold       'mew-face-header-private nil)
  (set-face-foreground 'mew-face-header-important nil)
  (set-face-bold       'mew-face-header-important nil)
  (set-face-foreground 'mew-face-header-marginal nil)
  (set-face-bold       'mew-face-header-marginal nil)
  ;;(set-face-foreground 'mew-face-header-warning nil)
  ;;(set-face-bold       'mew-face-header-warning nil)
  (set-face-foreground 'mew-face-header-xmew nil)
  (set-face-bold       'mew-face-header-xmew nil)
  (set-face-foreground 'mew-face-header-xmew-bad nil)
  (set-face-bold       'mew-face-header-xmew-bad nil)
  (set-face-foreground 'mew-face-body-url nil)
  (set-face-bold       'mew-face-body-url nil)
  (set-face-foreground 'mew-face-body-comment nil)
  (set-face-bold       'mew-face-body-comment nil)
  (set-face-foreground 'mew-face-body-cite1 nil)
  (set-face-bold       'mew-face-body-cite1 nil)
  (set-face-foreground 'mew-face-body-cite2 nil)
  (set-face-bold       'mew-face-body-cite2 nil)
  (set-face-foreground 'mew-face-body-cite3 nil)
  (set-face-bold       'mew-face-body-cite3 nil)
  (set-face-foreground 'mew-face-body-cite4 nil)
  (set-face-bold       'mew-face-body-cite4 nil)
  (set-face-foreground 'mew-face-body-cite5 nil)
  (set-face-bold       'mew-face-body-cite5 nil)
  (set-face-foreground 'mew-face-mark-review nil)
  (set-face-bold       'mew-face-mark-review nil)
  (set-face-foreground 'mew-face-mark-escape nil)
  (set-face-bold       'mew-face-mark-escape nil)
  (set-face-foreground 'mew-face-mark-delete nil)
  (set-face-bold       'mew-face-mark-delete nil)
  (set-face-foreground 'mew-face-mark-unlink nil)
  (set-face-bold       'mew-face-mark-unlink nil)
  (set-face-foreground 'mew-face-mark-refile nil)
  (set-face-bold       'mew-face-mark-refile nil)
  (set-face-foreground 'mew-face-mark-unread nil)
  (set-face-bold       'mew-face-mark-unread nil)
  (set-face-foreground 'mew-face-eof-message nil)
  (set-face-bold       'mew-face-eof-message nil)
  (set-face-foreground 'mew-face-eof-part nil)
  (set-face-bold       'mew-face-eof-part nil)
  ;;
  )

(cond
 ((< (display-color-cells) 256)
  (set-face-bold       'mew-face-header-subject t)
  (set-face-bold       'mew-face-header-from t)
  (set-face-bold       'mew-face-header-to t)
  (set-face-bold       'mew-face-header-xmew t)
  (set-face-bold       'mew-face-header-xmew-bad t)
  (set-face-bold       'mew-face-eof-message t)
  (set-face-bold       'mew-face-eof-part t)
  ;;
  )
 ((eq (frame-parameter nil 'background-mode) 'dark)
  (set-face-foreground 'mew-face-header-subject "gray89")
  (set-face-bold       'mew-face-header-subject t)
  (set-face-foreground 'mew-face-header-from "gray89")
  (set-face-bold       'mew-face-header-from t)
  (set-face-foreground 'mew-face-header-date "gray70")
  (set-face-foreground 'mew-face-header-to "gray89")
  (set-face-bold       'mew-face-header-to t)
  (set-face-foreground 'mew-face-header-key "gray70")
  (set-face-foreground 'mew-face-header-private "gray70")
  (set-face-foreground 'mew-face-header-important "gray70")
  (set-face-foreground 'mew-face-header-marginal "gray70")
  (set-face-foreground 'mew-face-header-xmew "gray70")
  (set-face-bold       'mew-face-header-xmew t)
  (set-face-foreground 'mew-face-header-xmew-bad "gray70")
  (set-face-bold       'mew-face-header-xmew-bad t)
  (set-face-foreground 'mew-face-body-cite1 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite2 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite3 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite4 "DarkSeaGreen")
  (set-face-foreground 'mew-face-body-cite5 "DarkSeaGreen")
  (set-face-foreground 'mew-face-eof-message "gray70")
  (set-face-bold       'mew-face-eof-message t)
  (set-face-foreground 'mew-face-eof-part "gray70")
  (set-face-bold       'mew-face-eof-part t)
  ;;
  )
 (t
  (set-face-foreground 'mew-face-header-subject "gray23")
  (set-face-bold       'mew-face-header-subject t)
  (set-face-foreground 'mew-face-header-from "gray23")
  (set-face-bold       'mew-face-header-from t)
  (set-face-foreground 'mew-face-header-date "gray58")
  (set-face-foreground 'mew-face-header-to "gray23")
  (set-face-bold       'mew-face-header-to t)
  (set-face-foreground 'mew-face-header-key "gray58")
  (set-face-foreground 'mew-face-header-private "gray58")
  (set-face-foreground 'mew-face-header-important "gray58")
  (set-face-foreground 'mew-face-header-marginal "gray58")
  (set-face-foreground 'mew-face-header-xmew "gray58")
  (set-face-bold       'mew-face-header-xmew t)
  (set-face-foreground 'mew-face-header-xmew-bad "gray58")
  (set-face-bold       'mew-face-header-xmew-bad t)
  (set-face-foreground 'mew-face-body-cite1 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite2 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite3 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite4 "DarkGreen")
  (set-face-foreground 'mew-face-body-cite5 "DarkGreen")
  (set-face-foreground 'mew-face-eof-message "gray58")
  (set-face-bold       'mew-face-eof-message t)
  (set-face-foreground 'mew-face-eof-part "gray58")
  (set-face-bold       'mew-face-eof-part t)
  ;;
  ))

;;; dot.mew-theme-subdued.el ends here
